@@ -15,4 +15,10 @@ test_that("Center hour drives get_hour outcome", {
       get_hour(x, hour_center = -12)
     as.numeric(comparison) == 24*60*60
   })
-})
\ No newline at end of file
+})
+
+test_that("StatHourglass doesn't throw an error", {
+  expect_no_error({
+    stat_hourglass()
+  })
+})
